import { Element, Props } from '../engine/reactive';
import { AlignContent, EdgeSize, FlexDirection, ObjectFit, ObjectPosition, TransformOrigin } from './types/DisplayObject';
import { ObservablePoint } from 'pixi.js';
import { BehaviorSubject } from 'rxjs';

export interface ComponentInstance extends PixiMixins.ContainerOptions {
    id?: string;
    children?: ComponentInstance[];
    onInit?(props: Props): void;
    onUpdate?(props: Props): void;
    onDestroy?(parent: Element, afterDestroy: () => void): void;
    onMount?(context: Element, index?: number): void;
    setWidth(width: number): void;
    setHeight(height: number): void;
}
export declare const EVENTS: string[];
export type OnHook = (() => void) | (() => Promise<void> | void);
export declare function DisplayObject(extendClass: any): {
    new (): {
        [x: string]: any;
        "__#1@#canvasContext": {
            [key: string]: any;
        } | null;
        isFlex: boolean;
        fullProps: Props;
        isMounted: boolean;
        _anchorPoints: ObservablePoint;
        isCustomAnchor: boolean;
        displayWidth: import('@signe/reactive').WritableSignal<number>;
        displayHeight: import('@signe/reactive').WritableSignal<number>;
        overrideProps: string[];
        layout: any;
        onBeforeDestroy: OnHook | null;
        onAfterMount: OnHook | null;
        subjectInit: BehaviorSubject<any>;
        disableLayout: boolean;
        "__#1@#registeredEvents": Map<string, Function>;
        readonly deltaRatio: any;
        readonly parentIsFlex: any;
        onInit(props: Props): void;
        onMount({ parent, props }: Element</*elided*/ any>, index?: number): Promise<void>;
        onUpdate(props: Props): void;
        onDestroy(parent: Element, afterDestroy?: () => void): Promise<void>;
        setFlexDirection(direction: FlexDirection): void;
        setFlexWrap(wrap: "wrap" | "nowrap" | "wrap-reverse"): void;
        setAlignContent(align: AlignContent): void;
        setAlignSelf(align: AlignContent): void;
        setAlignItems(align: AlignContent): void;
        setJustifyContent(justifyContent: "flex-start" | "flex-end" | "center" | "space-between" | "space-around"): void;
        setPosition(position: EdgeSize): void;
        setX(x: number): void;
        setY(y: number): void;
        setPadding(padding: EdgeSize): void;
        setMargin(margin: EdgeSize): void;
        setGap(gap: EdgeSize): void;
        setBorder(border: EdgeSize): void;
        setPositionType(positionType: "relative" | "absolute"): void;
        setWidth(width: number): void;
        setHeight(height: number): void;
        getWidth(): number;
        getHeight(): number;
        setMinWidth(minWidth: number | string): void;
        setMinHeight(minHeight: number | string): void;
        setMaxWidth(maxWidth: number | string): void;
        setMaxHeight(maxHeight: number | string): void;
        setAspectRatio(aspectRatio: number): void;
        setFlexGrow(flexGrow: number): void;
        setFlexShrink(flexShrink: number): void;
        setFlexBasis(flexBasis: number | string): void;
        setRowGap(rowGap: number): void;
        setColumnGap(columnGap: number): void;
        setTop(top: number | string): void;
        setLeft(left: number | string): void;
        setRight(right: number | string): void;
        setBottom(bottom: number | string): void;
        setObjectFit(objectFit: ObjectFit): void;
        setObjectPosition(objectPosition: ObjectPosition): void;
        setTransformOrigin(transformOrigin: TransformOrigin): void;
    };
    [x: string]: any;
};
//# sourceMappingURL=DisplayObject.d.ts.map