import { Signal } from '@signe/reactive';
import { Sprite as PixiSprite, Texture } from 'pixi.js';
import { Element } from '../engine/reactive';
import { AnimationFrames, FrameOptions, SpritesheetOptions, TextureOptions, TransformOptions } from './types/Spritesheet';
import { ComponentFunction } from '../engine/signal';
import { DisplayObjectProps } from './types/DisplayObject';
import { Layout } from '@pixi/layout';

type Image = {
    image: string;
};
type TextureOptionsMerging = TextureOptions & {
    spriteWidth: number;
    spriteHeight: number;
    sound?: string;
} & Image & TransformOptions;
type FrameOptionsMerging = TextureOptionsMerging & FrameOptions;
type SpritesheetOptionsMerging = TextureOptionsMerging & SpritesheetOptions;
type AnimationDataFrames = {
    sprites: FrameOptionsMerging[];
    frames: Texture[][];
    name: string;
    animations: AnimationFrames;
    params: any[];
    data: TextureOptionsMerging;
};
export declare enum StandardAnimation {
    Stand = "stand",
    Walk = "walk"
}
declare const CanvasSprite_base: {
    new (): {
        [x: string]: any;
        "__#1@#canvasContext": {
            [key: string]: any;
        } | null;
        isFlex: boolean;
        fullProps: import('..').Props;
        isMounted: boolean;
        _anchorPoints: import('pixi.js').ObservablePoint;
        isCustomAnchor: boolean;
        displayWidth: import('@signe/reactive').WritableSignal<number>;
        displayHeight: import('@signe/reactive').WritableSignal<number>;
        overrideProps: string[];
        layout: any;
        onBeforeDestroy: import('./DisplayObject').OnHook | null;
        onAfterMount: import('./DisplayObject').OnHook | null;
        subjectInit: import('rxjs').BehaviorSubject<any>;
        disableLayout: boolean;
        "__#1@#registeredEvents": Map<string, Function>;
        readonly deltaRatio: any;
        readonly parentIsFlex: any;
        onInit(props: import('..').Props): void;
        onMount({ parent, props }: Element</*elided*/ any>, index?: number): Promise<void>;
        onUpdate(props: import('..').Props): void;
        onDestroy(parent: Element, afterDestroy?: () => void): Promise<void>;
        setFlexDirection(direction: import('./types/DisplayObject').FlexDirection): void;
        setFlexWrap(wrap: "wrap" | "nowrap" | "wrap-reverse"): void;
        setAlignContent(align: import('./types/DisplayObject').AlignContent): void;
        setAlignSelf(align: import('./types/DisplayObject').AlignContent): void;
        setAlignItems(align: import('./types/DisplayObject').AlignContent): void;
        setJustifyContent(justifyContent: "flex-start" | "flex-end" | "center" | "space-between" | "space-around"): void;
        setPosition(position: import('./types/DisplayObject').EdgeSize): void;
        setX(x: number): void;
        setY(y: number): void;
        setPadding(padding: import('./types/DisplayObject').EdgeSize): void;
        setMargin(margin: import('./types/DisplayObject').EdgeSize): void;
        setGap(gap: import('./types/DisplayObject').EdgeSize): void;
        setBorder(border: import('./types/DisplayObject').EdgeSize): void;
        setPositionType(positionType: "relative" | "absolute"): void;
        setWidth(width: number): void;
        setHeight(height: number): void;
        getWidth(): number;
        getHeight(): number;
        setMinWidth(minWidth: number | string): void;
        setMinHeight(minHeight: number | string): void;
        setMaxWidth(maxWidth: number | string): void;
        setMaxHeight(maxHeight: number | string): void;
        setAspectRatio(aspectRatio: number): void;
        setFlexGrow(flexGrow: number): void;
        setFlexShrink(flexShrink: number): void;
        setFlexBasis(flexBasis: number | string): void;
        setRowGap(rowGap: number): void;
        setColumnGap(columnGap: number): void;
        setTop(top: number | string): void;
        setLeft(left: number | string): void;
        setRight(right: number | string): void;
        setBottom(bottom: number | string): void;
        setObjectFit(objectFit: import('./types/DisplayObject').ObjectFit): void;
        setObjectPosition(objectPosition: import('./types/DisplayObject').ObjectPosition): void;
        setTransformOrigin(transformOrigin: import('./types/DisplayObject').TransformOrigin): void;
    };
    [x: string]: any;
};
export declare class CanvasSprite extends CanvasSprite_base {
    hitbox: {
        w: number;
        h: number;
    };
    applyTransform: (frame: FrameOptionsMerging, data: TextureOptionsMerging, spritesheet: SpritesheetOptionsMerging) => Partial<FrameOptionsMerging>;
    private spritesheet;
    private currentAnimation;
    private time;
    private frameIndex;
    private animations;
    private subscriptionTick;
    private subscriptionSheet;
    private sheetParams;
    private sheetCurrentAnimation;
    private app;
    onFinish: () => void;
    get renderer(): import('pixi.js').Renderer;
    private currentAnimationContainer;
    private createTextures;
    private createAnimations;
    onMount(params: Element<CanvasSprite>): Promise<void>;
    onUpdate(props: any): Promise<void>;
    onDestroy(parent: Element, afterDestroy: () => void): Promise<void>;
    has(name: string): boolean;
    get(name: string): AnimationDataFrames;
    isPlaying(name?: string): boolean;
    stop(): void;
    play(name: string, params?: any[]): void;
    update({ deltaRatio }: {
        deltaRatio: any;
    }): void;
}
export interface CanvasSprite extends PixiSprite {
    layout: Layout | null;
}
export interface SpriteProps extends DisplayObjectProps {
    sheet?: {
        definition?: SpritesheetOptionsMerging;
        playing?: string;
        params?: any;
        onFinish?: () => void;
    };
    scaleMode?: number;
    image?: string;
    rectangle?: {
        x: number;
        y: number;
        width: number;
        height: number;
    };
    context?: {
        tick: Signal;
    };
}
export interface SpritePropsWithImage extends Omit<SpriteProps, "sheet"> {
    image: string;
    rectangle?: {
        x: number;
        y: number;
        width: number;
        height: number;
    };
}
export interface SpritePropsWithSheet extends Omit<SpriteProps, "image" | "rectangle"> {
    sheet: {
        definition: SpritesheetOptionsMerging;
        playing?: string;
        params?: any;
        onFinish?: () => void;
    };
    loader?: {
        onProgress?: (progress: number) => void;
        onComplete?: (texture: Texture) => void;
    };
}
export type SpritePropTypes = SpritePropsWithImage | SpritePropsWithSheet;
export declare const Sprite: ComponentFunction<SpritePropTypes>;
export {};
//# sourceMappingURL=Sprite.d.ts.map