import { Element, Props } from '../engine/reactive';
import { ComponentInstance } from './DisplayObject';

export interface ViewportProps extends Props {
    screenWidth?: number;
    screenHeight?: number;
    worldWidth?: number;
    worldHeight?: number;
    clamp?: boolean | {
        left?: number;
        right?: number;
        top?: number;
        bottom?: number;
    };
    context?: any;
    [key: string]: any;
}
declare const CanvasViewport_base: {
    new (): {
        [x: string]: any;
        "__#1@#canvasContext": {
            [key: string]: any;
        } | null;
        isFlex: boolean;
        fullProps: Props;
        isMounted: boolean;
        _anchorPoints: import('pixi.js').ObservablePoint;
        isCustomAnchor: boolean;
        displayWidth: import('@signe/reactive').WritableSignal<number>;
        displayHeight: import('@signe/reactive').WritableSignal<number>;
        overrideProps: string[];
        layout: any;
        onBeforeDestroy: import('./DisplayObject').OnHook | null;
        onAfterMount: import('./DisplayObject').OnHook | null;
        subjectInit: import('rxjs').BehaviorSubject<any>;
        disableLayout: boolean;
        "__#1@#registeredEvents": Map<string, Function>;
        readonly deltaRatio: any;
        readonly parentIsFlex: any;
        onInit(props: Props): void;
        onMount({ parent, props }: Element</*elided*/ any>, index?: number): Promise<void>;
        onUpdate(props: Props): void;
        onDestroy(parent: Element, afterDestroy?: () => void): Promise<void>;
        setFlexDirection(direction: import('./types/DisplayObject').FlexDirection): void;
        setFlexWrap(wrap: "wrap" | "nowrap" | "wrap-reverse"): void;
        setAlignContent(align: import('./types/DisplayObject').AlignContent): void;
        setAlignSelf(align: import('./types/DisplayObject').AlignContent): void;
        setAlignItems(align: import('./types/DisplayObject').AlignContent): void;
        setJustifyContent(justifyContent: "flex-start" | "flex-end" | "center" | "space-between" | "space-around"): void;
        setPosition(position: import('./types/DisplayObject').EdgeSize): void;
        setX(x: number): void;
        setY(y: number): void;
        setPadding(padding: import('./types/DisplayObject').EdgeSize): void;
        setMargin(margin: import('./types/DisplayObject').EdgeSize): void;
        setGap(gap: import('./types/DisplayObject').EdgeSize): void;
        setBorder(border: import('./types/DisplayObject').EdgeSize): void;
        setPositionType(positionType: "relative" | "absolute"): void;
        setWidth(width: number): void;
        setHeight(height: number): void;
        getWidth(): number;
        getHeight(): number;
        setMinWidth(minWidth: number | string): void;
        setMinHeight(minHeight: number | string): void;
        setMaxWidth(maxWidth: number | string): void;
        setMaxHeight(maxHeight: number | string): void;
        setAspectRatio(aspectRatio: number): void;
        setFlexGrow(flexGrow: number): void;
        setFlexShrink(flexShrink: number): void;
        setFlexBasis(flexBasis: number | string): void;
        setRowGap(rowGap: number): void;
        setColumnGap(columnGap: number): void;
        setTop(top: number | string): void;
        setLeft(left: number | string): void;
        setRight(right: number | string): void;
        setBottom(bottom: number | string): void;
        setObjectFit(objectFit: import('./types/DisplayObject').ObjectFit): void;
        setObjectPosition(objectPosition: import('./types/DisplayObject').ObjectPosition): void;
        setTransformOrigin(transformOrigin: import('./types/DisplayObject').TransformOrigin): void;
    };
    [x: string]: any;
};
export declare class CanvasViewport extends CanvasViewport_base {
    private tickSubscription;
    overrideProps: string[];
    constructor();
    onInit(props: any): void;
    /**
     * Called when the component is mounted to the scene graph.
     * Initializes viewport settings and subscriptions.
     * @param {Element<CanvasViewport>} element - The element being mounted. Its `props` property (of type ViewportProps) contains component properties and context.
     * @param {number} [index] - The index of the component among its siblings.
     */
    onMount(element: Element<CanvasViewport>, index?: number): Promise<void>;
    onUpdate(props: any): void;
    private updateViewportSettings;
    /**
     * Called when the component is about to be destroyed.
     * Unsubscribes from the tick observable.
     * @param {Element<any>} parent - The parent element.
     * @param {() => void} [afterDestroy] - An optional callback function to be executed after the component's own destruction logic.
     */
    onDestroy(parent: Element<any>, afterDestroy?: () => void): Promise<void>;
}
export declare function Viewport(props: ViewportProps): Element<ComponentInstance>;
export {};
//# sourceMappingURL=Viewport.d.ts.map