import { Container, FederatedPointerEvent } from 'pixi.js';
import { Directive } from '../engine/directive';
import { Element } from '../engine/reactive';
import { SignalOrPrimitive } from '../components/types';

export type DragProps = {
    move?: (event: FederatedPointerEvent) => void;
    start?: () => void;
    end?: () => void;
    snap?: SignalOrPrimitive<number>;
    direction?: SignalOrPrimitive<'x' | 'y' | 'all'>;
    keyToPress?: SignalOrPrimitive<string[]>;
    viewport?: {
        edgeThreshold?: SignalOrPrimitive<number>;
        maxSpeed?: SignalOrPrimitive<number>;
    };
};
export declare class Drop extends Directive {
    private elementRef;
    onInit(element: Element<Container>): void;
    onMount(element: Element<Container>): void;
    onUpdate(): void;
    onDestroy(): void;
}
export declare class Drag extends Directive {
    private elementRef;
    private stageRef;
    private offsetInParent;
    private isDragging;
    private viewport;
    private animationFrameId;
    private lastPointerPosition;
    private pressedKeys;
    private pointerIsDown;
    private onDragMoveHandler;
    private onDragEndHandler;
    private onDragStartHandler;
    private onKeyDownHandler;
    private onKeyUpHandler;
    private subscriptions;
    onInit(element: Element<Container>): void;
    onMount(element: Element<Container>): void;
    get dragProps(): any;
    get axis(): {
        x: boolean;
        y: boolean;
    };
    /**
     * Updates element position when dragging and starts continuous viewport movement
     * @param event The pointer event that triggered the drag move
     */
    private onDragMove;
    /**
     * Moves the viewport if the dragged element is near screen edges
     * @param globalPosition The global pointer position
     */
    private updateViewportPosition;
    /**
     * Handles drag end event and stops viewport movement
     */
    private onDragEnd;
    onKeyDown(event: KeyboardEvent): void;
    onKeyUp(event: KeyboardEvent): void;
    private areRequiredKeysPressed;
    private onPointerDown;
    private startDrag;
    onUpdate(props: any): void;
    onDestroy(): void;
}
//# sourceMappingURL=Drag.d.ts.map