interface Listen<T = any> {
    config: T | undefined;
    seed: {
        config: T | undefined;
        value: number;
        resolve: (value: any) => void;
    };
}
interface Trigger<T = any> {
    start: () => Promise<void>;
    listen: () => Listen<T> | undefined;
}
/**
 * Checks if the given argument is a Trigger object
 * @param arg - The value to check
 * @returns True if the argument is a Trigger object
 */
export declare function isTrigger(arg: any): arg is Trigger<any>;
/**
 * Creates a new trigger that can be used to pass data between components
 * @param globalConfig - Optional configuration data to be passed when the trigger is activated
 * @returns A Trigger object with start and listen methods
 * @example
 * ```ts
 * const myTrigger = trigger()
 *
 * on(myTrigger, (data) => {
 *   console.log('Triggered with data:', data)
 * })
 *
 * myTrigger.start({ message: 'Hello' })
 * ```
 */
export declare function trigger<T = any>(globalConfig?: T): Trigger<T>;
/**
 * Subscribes to a trigger and executes a callback when the trigger is activated
 * @param triggerSignal - The trigger to subscribe to
 * @param callback - Function to execute when the trigger is activated
 * @throws Error if triggerSignal is not a valid trigger
 * @example
 * ```ts
 * const click = trigger()
 *
 * on(click, () => {
 *   console.log('Click triggered')
 * })
 * ```
 */
export declare function on(triggerSignal: any, callback: (config: any) => void | Promise<void>): void;
export {};
//# sourceMappingURL=trigger.d.ts.map