import { ObservablePoint } from 'pixi.js';

/**
 * Checks if code is running in a browser environment
 * @returns {boolean} True if running in browser, false otherwise
 */
export declare function isBrowser(): boolean;
/**
 * Returns current high-resolution timestamp
 * @returns {number} Current time in milliseconds
 */
export declare function preciseNow(): number;
/**
 * Converts frames per second to milliseconds
 * @param {number} fps - Frames per second
 * @returns {number} Milliseconds per frame
 */
export declare function fps2ms(fps: number): number;
/**
 * Checks if a value is a Promise
 * @param {any} value - Value to check
 * @returns {boolean} True if value is a Promise, false otherwise
 */
export declare function isPromise(value: any): boolean;
export declare function arrayEquals(a: any[], b: any[]): boolean;
/**
 * Checks if a value is a function
 * @param {unknown} val - Value to check
 * @returns {boolean} True if value is a function, false otherwise
 */
export declare function isFunction(val: unknown): boolean;
/**
 * Checks if a value is a plain object (not an instance of a class)
 * @param {unknown} val - Value to check
 * @returns {boolean} True if value is a plain object (not null, not array, not instance), false otherwise
 * @example
 * ```ts
 * isObject({}) // true
 * isObject(new Date()) // false
 * isObject([]) // false
 * isObject(null) // false
 * ```
 */
export declare function isObject(val: unknown): boolean;
export declare function isObservable(val: unknown): boolean;
/**
 * Sets a value in an object using a dot notation path
 * @param {Record<string, any>} obj - Target object
 * @param {string | string[]} path - Path to set value at (e.g., 'a.b.c' or ['a', 'b', 'c'])
 * @param {any} value - Value to set
 * @param {boolean} onlyPlainObject - If true, only creates plain objects in path
 * @returns {Record<string, any>} Modified object
 */
export declare function set(obj: Record<string, any>, path: string | string[], value: any, onlyPlainObject?: boolean): Record<string, any>;
/**
 * Gets a value from an object using a dot notation path
 * @param {Record<string, any>} obj - Source object
 * @param {string} path - Path to get value from (e.g., 'a.b.c')
 * @returns {any} Value at path or undefined if not found
 */
export declare function get(obj: Record<string, any>, path: string): any;
/**
 * Logs a message to console
 * @param {any} text - Message to log
 */
export declare function log(text: any): void;
/**
 * Logs an error message to console
 * @param {any} text - Error message to log
 */
export declare function error(text: any): void;
/**
 * Sets the position of an ObservablePoint using various input formats
 * @param {ObservablePoint} observablePoint - The point to modify
 * @param {Object | number | [number, number]} point - New position value
 */
export declare function setObservablePoint(observablePoint: ObservablePoint, point: {
    x: number;
    y: number;
} | number | [number, number]): void;
/**
 * Calculates the Euclidean distance between two points
 * @param {number} x1 - X coordinate of first point
 * @param {number} y1 - Y coordinate of first point
 * @param {number} x2 - X coordinate of second point
 * @param {number} y2 - Y coordinate of second point
 * @returns {number} Distance between the points
 */
export declare function calculateDistance(x1: number, y1: number, x2: number, y2: number): number;
//# sourceMappingURL=utils.d.ts.map