import { Texture, Matrix } from 'pixi.js';

/**
 * Creates a radial gradient texture that can be used in PixiJS.
 * @example
 * const gradient = new RadialGradient(size, size, 0, size, size, 0);
 * gradient.addColorStop(0, "rgba(255, 255, 0, 1)");
 * gradient.addColorStop(0.5, "rgba(255, 255, 0, 0.3)");
 * gradient.addColorStop(0.8, "rgba(255, 255, 0, 0)");
 */
export declare class RadialGradient {
    private x0;
    private y0;
    private x1;
    private y1;
    private x2;
    private y2;
    private focalPoint;
    private canvas;
    private ctx;
    private gradient;
    private texture;
    transform: Matrix;
    size: number;
    /**
     * Creates a new RadialGradient instance
     * @param x0 - The x-coordinate of the starting circle
     * @param y0 - The y-coordinate of the starting circle
     * @param x1 - The x-coordinate of the ending circle
     * @param y1 - The y-coordinate of the ending circle
     * @param x2 - The x-coordinate for gradient transformation
     * @param y2 - The y-coordinate for gradient transformation
     * @param focalPoint - The focal point of the gradient (0-1), defaults to 0
     */
    constructor(x0: number, y0: number, x1: number, y1: number, x2: number, y2: number, focalPoint?: number);
    /**
     * Adds a color stop to the gradient
     * @param offset - The position of the color stop (0-1)
     * @param color - The color value (any valid CSS color string)
     */
    addColorStop(offset: number, color: string): void;
    /**
     * Renders the gradient and returns the texture with its transformation matrix
     * @param options - Render options
     * @param options.translate - Optional translation coordinates
     * @returns Object containing the texture and transformation matrix
     */
    render({ translate }?: {
        translate?: {
            x: number;
            y: number;
        };
    }): {
        texture: Texture<import('pixi.js').TextureSource<any>>;
        matrix: Matrix;
    };
}
//# sourceMappingURL=RadialGradient.d.ts.map